pub struct Args {
pub essence_file: PathBuf,
pub param_file: Option<PathBuf>,
pub info_json_path: Option<PathBuf>,
pub no_run_solver: bool,
pub number_of_solutions: NumberOfSolutions,
pub output_format: OutputFormat,
pub solutions_in_one_file: bool,
pub output: Option<PathBuf>,
pub keep_intermediate_solutions: bool,
}Fields
essence_file: PathBufThe input Essence problem file
param_file: Option<PathBuf>The input Essence parameter file
info_json_path: Option<PathBuf>Save execution info as JSON to the given filepath.
no_run_solver: boolDo not run the solver.
The rewritten model is printed to stdout in an Essence-style syntax (but is not necessarily valid Essence).
number_of_solutions: NumberOfSolutionsNumber of solutions to return. Use a positive integer, or all.
output_format: OutputFormatFormat for printed / saved solutions
solutions_in_one_file: boolWrite all solutions into a single file (default: true).
Pass --solutions-in-one-file=false to emit one file (or stdout record) per solution.
output: Option<PathBuf>Save solutions to the given path (Essence .solutions / JSON .solutions.json, or a
filename stem when --solutions-in-one-file=false)
keep_intermediate_solutions: boolWhen optimising, retain every improving solution Minion reports instead of only the last one.