pub struct GlobalArgs {Show 16 fields
pub extra_rule_sets: Vec<String>,
pub verbose: bool,
pub check_equally_applicable_rules: bool,
pub rule_trace: Option<PathBuf>,
pub rule_trace_verbose: Option<PathBuf>,
pub _no_check_equally_applicable_rules: bool,
pub parser: Parser,
pub rewriter: Rewriter,
pub comprehension_expander: QuantifiedExpander,
pub solver: SolverFamily,
pub minion_discrete_threshold: usize,
pub save_solver_input_file: Option<PathBuf>,
pub solver_timeout: Option<Duration>,
pub log: bool,
pub logfile: Option<PathBuf>,
pub logfile_json: Option<PathBuf>,
}Fields
extra_rule_sets: Vec<String>Extra rule sets to enable
verbose: boolLog verbosely
check_equally_applicable_rules: boolCheck for multiple equally applicable rules, exiting if any are found.
Only compatible with the default rewriter.
rule_trace: Option<PathBuf>Output file for the human readable rule trace.
rule_trace_verbose: Option<PathBuf>Output file for verbose rule-attempt trace in CSV format.
Each row includes: elapsed_s, rule_level, rule_name, rule_set, status, expression.
_no_check_equally_applicable_rules: boolDo not check for multiple equally applicable rules [default].
Only compatible with the default rewriter.
parser: ParserWhich parser to use.
Possible values: tree-sitter, via-conjure.
rewriter: RewriterWhich rewriter to use.
Possible values: naive, morph.
comprehension_expander: QuantifiedExpanderWhich strategy to use for expanding quantified variables in comprehensions.
Possible values: native, via-solver, via-solver-ac.
solver: SolverFamilySolver family to use.
Possible values: minion, sat, sat-log, sat-direct, sat-order,
smt[-<ints>][-<matrices>][-nodiscrete]
where <ints> is lia or bv, and <matrices> is arrays or atomic.
minion_discrete_threshold: usizeInt-domain size threshold for using Minion DISCRETE variables.
If an int domain has size <= this value, Conjure Oxide emits DISCRETE; otherwise BOUND.
save_solver_input_file: Option<PathBuf>Save a solver input file to
This input file will be in a format compatible by the command-line interface of the selected solver. For example, when the solver is Minion, a valid .minion file will be output.
This file is for informational purposes only; the results of running this file cannot be used by Conjure Oxide in any way.
solver_timeout: Option<Duration>Stop the solver after the given timeout.
Currently only SMT supports this feature.
log: boolGenerate log files
logfile: Option<PathBuf>Output file for conjure-oxide’s text logs
logfile_json: Option<PathBuf>Output file for conjure-oxide’s json logs