pub struct GlobalArgs {Show 15 fields
pub extra_rule_sets: Vec<String>,
pub verbose: bool,
pub check_equally_applicable_rules: bool,
pub human_rule_trace: Option<PathBuf>,
pub _no_check_equally_applicable_rules: bool,
pub parser: Parser,
pub rewriter: Rewriter,
pub quantified_expander: QuantifiedExpander,
pub solver: SolverFamily,
pub save_solver_input_file: Option<PathBuf>,
pub exit_after_unrolling: bool,
pub solver_timeout: Option<Duration>,
pub log: bool,
pub logfile: Option<PathBuf>,
pub logfile_json: Option<PathBuf>,
}Fields
extra_rule_sets: Vec<String>Extra rule sets to enable
verbose: boolLog verbosely
check_equally_applicable_rules: boolCheck for multiple equally applicable rules, exiting if any are found.
Only compatible with the default rewriter.
human_rule_trace: Option<PathBuf>Output file for the human readable rule trace.
_no_check_equally_applicable_rules: boolDo not check for multiple equally applicable rules [default].
Only compatible with the default rewriter.
parser: ParserWhich parser to use.
Possible values: tree-sitter, via-conjure.
rewriter: RewriterWhich rewriter to use.
Possible values: naive, morph.
quantified_expander: QuantifiedExpanderWhich strategy to use for expanding quantified variables in comprehensions.
Possible values: native, via-solver, via-solver-ac.
solver: SolverFamilySolver family to use.
Possible values: minion, sat, sat-log, sat-direct, sat-order;
with smt feature: smt and smt-<ints>-<matrices>[-nodiscrete]
where <ints> is lia or bv, and <matrices> is arrays or atomic.
save_solver_input_file: Option<PathBuf>Save a solver input file to
This input file will be in a format compatible by the command-line interface of the selected solver. For example, when the solver is Minion, a valid .minion file will be output.
This file is for informational purposes only; the results of running this file cannot be used by Conjure Oxide in any way.
exit_after_unrolling: boolExit after all comprehensions have been unrolled, printing the number of expressions at that point.
This is only compatible with the default rewriter.
This flag is useful to compare how comprehension optimisations, such as expand-ac, effect rewriting.
solver_timeout: Option<Duration>Stop the solver after the given timeout.
Currently only SMT supports this feature.
log: boolGenerate log files
logfile: Option<PathBuf>Output file for conjure-oxide’s text logs
logfile_json: Option<PathBuf>Output file for conjure-oxide’s json logs